@@ -308,73 +308,6 @@ class ARTStabilityTest(unittest.TestCase):
         self.assertEqual('red', self.__metric.status())
 
 
-class FakeNagios(object):
-    ''' Fake Nagios for testing purposes. '''
-    @staticmethod
-    def number_of_servers_sufficiently_available():  
-        # pylint: disable=invalid-name
-        ''' Fake the number of available servers. '''
-        return 10
-
-    @staticmethod
-    def number_of_servers():
-        ''' Fake the number of servers. '''
-        return 12
-
-    @staticmethod
-    def number_of_servers_per_group():
-        ''' Fake the server groups. '''
-        return dict(group1=4, group2=8)
-
-    @staticmethod
-    def availability_url():
-        ''' Fake the Nagios url. '''
-        return 'http://nagios'
-
-
-class ServerAvailabilityTest(unittest.TestCase):
-    # pylint: disable=too-many-public-methods
-    ''' Unit tests for the server availability metric. '''
-
-    def setUp(self):  # pylint: disable=invalid-name
-        self.__project = domain.Project(nagios=FakeNagios())
-        self.__team = domain.Team('Support team', is_support_team=True)
-        self.__metric = metric.ServerAvailability(subject=self.__team, 
-                                                  project=self.__project)
-
-    def test_value(self):
-        ''' Test that the availability is reported correctly. '''
-        self.assertEqual(83., self.__metric.value())
-
-    def test_report(self):
-        ''' Test that the report is correct. '''
-        self.assertEqual('Servers met voldoende beschikbaarheid is 83% ' \
-                         '(10 van 12). Aantal servers per groep: group1: 4, ' \
-                         'group2: 8.', self.__metric.report())
-
-    def test_url(self):
-        ''' Test that the url is correct. '''
-        self.assertEqual(dict(Nagios='http://nagios'), self.__metric.url())
-
-    def test_can_be_measured(self):
-        ''' Test that the metric can be measured for support teams if Nagios
-            is available. '''
-        self.failUnless(metric.ServerAvailability.\
-                        can_be_measured(self.__team, self.__project))
-
-    def test_cant_be_measured_for_scrum_teams(self):
-        ''' Test that the metric can only be measured for support teams. '''
-        team = domain.Team('Scrum team', is_scrum_team=True)
-        self.failIf(metric.ServerAvailability.can_be_measured(team,
-                                                              self.__project))
-
-    def test_cant_be_measured_without_nagios(self):
-        ''' Test that the metric can not be measured without Nagios. '''
-        project = domain.Project()
-        self.failIf(metric.ServerAvailability.can_be_measured(self.__team,
-                                                              project))
-
-
 class AssignedCIJobsTest(unittest.TestCase):
     # pylint: disable=too-many-public-methods
     ''' Unit tests for the assigned CI jobs metric. '''
